Learn R Programming

groupedHyperframe.random (version 0.2.2)

.rppp: Simulate (Marked) Point Pattern

Description

To generate ppp.object(s), with none or one or multiple marks.

Usage

.rppp(
  ...,
  dots,
  win = square(),
  n = 1L,
  element1 = TRUE,
  envir = parent.frame()
)

Value

Function .rppp() returns a ppp.object if (n==1L)&element1, otherwise returns a length-n

solist

(which also has class

'ppplist').

The returned ppp.object(s) contain only \(x\)- and \(y\)-coords, if only one call is present in the ...

dyn-dots argument. Otherwise, they contain one or more marks

according to the rest of the call(s) in the ... argument.

Arguments

...

see vignettes

dots

(for internal use) list of one or more named lists. The first list specifies the parameters to generate the \(x\)- and \(y\)-coords. The second to last lists, if available, specify the parameters to generate one or more marks.

win

owin.object

n

integer scalar, number of ppp.objects to generate. Default 1L.

element1

logical scalar, whether to return a ppp.object, instead of a length-1L solist, when n==1L. Default TRUE

envir

environment, in which to evaluate the ... dyn-dots argument. Default is the parent.frame.