groupedHyperframe.random-package: groupedHyperframe.random: Simulated Grouped Hyper Data Frame

groupedHyperframe.random-packageR Documentation

groupedHyperframe.random: Simulated Grouped Hyper Data Frame

Description

An intuitive interface to simulate (1) superimposed (marked) point patterns with vectorized parameterization of random point pattern and distribution of marks; and (2) grouped hyper data frame based on population parameters and subject-specific random effects.

Author(s)

Maintainer: Tingting Zhan tingtingzhan@gmail.com (ORCID)

Other contributors:

See Also

Useful links:


groupedHyperframe.random documentation built on Jan. 25, 2026, 1:06 a.m.