| groupedHyperframe.random-package | R Documentation |
An intuitive interface to simulate (1) superimposed (marked) point patterns with vectorized parameterization of random point pattern and distribution of marks; and (2) grouped hyper data frame based on population parameters and subject-specific random effects.
Maintainer: Tingting Zhan tingtingzhan@gmail.com (ORCID)
Other contributors:
Inna Chervoneva Inna.Chervoneva@jefferson.edu (ORCID) [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.